<?php
/**
 * Custom functions for the theme options.
 *
 * @package    Mystery
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Theme options header.
 *
 * @since  1.0.0
 */
function mystery_of_header() {
	$theme = wp_get_theme();
	$name  = $theme->get( 'TextDomain' );
?>
	<div class="header-options">
		<ul class="theme-info">
			<li><span class="dashicons dashicons-info"></span><a href="http://docs.theme-junkie.com/<?php echo esc_attr( $name ); ?>" target="_blank"><?php _e( 'Documentation', 'mystery' ); ?></a></li>
			<li><span class="dashicons dashicons-lightbulb"></span><a href="http://www.theme-junkie.com/forum/" target="_blank"><?php _e( 'Support Forum', 'mystery' ); ?></a></li>
			<li><span class="dashicons dashicons-twitter"></span><a href="https://twitter.com/theme_junkie" target="_blank">Follow Us</a></li>
			<li><span class="dashicons dashicons-facebook"></span><a href="https://www.facebook.com/themejunkies" target="_blank">Like Us</a></li>
		</ul>
	</div>
<?php
}
add_action( 'optionsframework_header_options', 'mystery_of_header' );

/**
 * Sticky navigation
 *
 * @since  1.0.0
 */
function mystery_sticky_navigation() {
	$sticky = of_get_option( 'mystery_sticky_nav', 'secondary' );
?>
	<?php if ( $sticky != 'disable' ) : ?>
	<script type="text/javascript">
	$(document).ready(function() {
		<?php if ( $sticky == 'primary' ) : ?>
			$("#primary-bar").sticky( { topSpacing: 0 } ); 
		<?php elseif ( $sticky == 'secondary' ) : ?>
			$("#secondary-bar").sticky( { topSpacing: 0 } );
		<?php endif; ?>
	});
	</script>
	<?php endif; ?>
<?php
}
add_action( 'wp_footer', 'mystery_sticky_navigation', 999 );

/**
 * Favicon output.
 *
 * @since 1.0.0
 */
function mystery_favicon_output() {
	$favicon = of_get_option( 'mystery_favicon' );

	if ( !empty( $favicon ) ) {
		echo '<link href="' . esc_url( $favicon ) . '" rel="icon">' . "\n";
	}

}
add_action( 'wp_head', 'mystery_favicon_output', 5 );

/**
 * Mobile Icon output.
 *
 * @since 1.0.0
 */
function mystery_mobile_icon_output() {
	$icon = of_get_option( 'mystery_mobile_icon' );

	if ( !empty( $icon ) ) {
		echo '<link rel="apple-touch-icon-precomposed" href="' . esc_url( $icon ) . '">' . "\n";
	}

}
add_action( 'wp_head', 'mystery_mobile_icon_output', 6 );

/**
 * Custom RSS feed url.
 *
 * @since  1.0.0
 * @return string
 */
function mystery_feed_url( $output, $feed ) {

	// Get the custom rss feed url.
	$url = of_get_option( 'mystery_feedburner_url' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( !empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'mystery_feed_url', 10, 2 );

/**
 * Accent Colors
 *
 * @since  1.0.0
 */
function mystery_accent_colors() {

	$option  = of_get_option( 'mystery_colors', 'blue' );
	$pallete = of_get_option( 'mystery_color_pallete', '#00aeef' );
	$color   = '#00aeef';
	$color1  = '#f5f5f5';
	$color2  = '#e9e9e9';

	if ( $option == 'blue' ) {
		$color1 = '#ddf0f9';
		$color2 = '#c7e6f5'; 
	}

	if ( $option == 'green' ) {
		$color  = '#37B248';
	}

	if ( $option == 'deep-green' ) {
		$color  = '#228B22';
	}

	if ( $option == 'dark-green' ) {
		$color  = '#8FBC8F';
	}

	if ( $option == 'turqouise' ) {
		$color  = '#00CED1';
	}

	if ( $pallete != '#00aeef' && $pallete != '' ) {
		$color   = $pallete;
		$color1  = '#f5f5f5';
		$color2  = '#e9e9e9';
	}
	?>
	<style>

		#secondary-bar,
		#secondary-bar .slicknav_menu,		
		.pagination .page-numbers.current,
		#respond button,
		a:hover .video-icon,
		.button,
		a.button,
		button,
		input[type=button],
		input[type=submit],
		.widget_tabs .tab-content ul li a:hover,
		.widget_tabs #tab4 a:hover { 
			background-color: <?php echo $color ?>;
		}

		a:link,
		a:visited,
		#secondary-bar .slicknav_nav a,		
		#secondary-nav ul.sf-menu li li a:hover,
		#primary-nav ul.sf-menu li li a:hover,
		#secondary-nav .sf-menu li li a:hover,
		.widget_tabs .tab-content .entry-title a:hover,
		#site-bottom a:hover,
		.sidebar2 .widget_tabs .tabs-nav li.active a,
		.category-box ul li strong a:hover,
		.section-title a:hover,
		.widget_latest_comments a:hover .name,
		.related-posts ul li a:hover .entry-title,
		.widget_tabs .entry-title a:hover,
		.posts .cat-posts .view-more a,
		.posts .cat-posts a:hover .entry-title,
		li a:hover .fa-star,
		li.active .fa-star,
		#primary-nav ul li a:hover, 
		#primary-nav ul li.sfHover a, 
		#primary-nav ul li.current_item a,
		#secondary-nav ul li a:hover,
		#secondary-nav ul li.current_item a,
		#secondary-nav ul li.sfHover a,
		#secondary-nav ul.sf-menu li li a,
		.posts .sub-cats li:hover > a:after,
		.entry-comments,
		.black a:hover, .single .entry-meta .entry-author a:hover,
		.widget_tabs .tabs-nav li a:hover,
		.footer-dark .widget a:hover  {
			color: <?php echo $color ?>;
		}

		.sf-arrows > li > .sf-with-ul:focus:after,
		.sf-arrows > li:hover > .sf-with-ul:after,
		.sf-arrows > .sfHover > .sf-with-ul:after,
		#primary-nav .sf-arrows > li > .sf-with-ul:focus:after,
		#primary-nav .sf-arrows > li:hover > .sf-with-ul:after,
		#primary-nav .sf-arrows > .sfHover > .sf-with-ul:after {
			border-top-color: <?php echo $color ?>;
		}

		.sf-arrows ul .sf-with-ul:after,
		.sf-arrows ul li > .sf-with-ul:focus:after,
		.sf-arrows ul li:hover > .sf-with-ul:after,
		.sf-arrows ul .sfHover > .sf-with-ul:after {
			border-left-color: <?php echo $color ?>;
		}
		
		#secondary-bar .slicknav_nav,
		#secondary-nav .sf-menu ul,
		#secondary-nav .sf-mega {
			border-bottom: 5px solid <?php echo $color ?>;
		}

		#secondary-nav .sf-menu ul,
		#secondary-nav ul li a:hover,
		#secondary-nav ul li.current_item a,
		#secondary-nav ul li.sfHover a,
		#secondary-nav .sf-mega,
		.posts .sub-cats li a:hover {
			background-color: <?php echo $color1 ?>;
		}

		.posts .sub-cats li a:hover {
			background-color: <?php echo $color1 ?> !important;
		}

		.posts .sub-cats {
			background-color: <?php echo $color2 ?>;
		}
	</style>
	<?php
}
add_action( 'wp_head', 'mystery_accent_colors', 20 );

/**
 * Single post advertisement.
 * Before content.
 *
 * @since  1.0.0
 */
function mystery_single_ad_before( $content ) {
	$ad = of_get_option( 'mystery_ad_single_before' );

	if ( is_single() ) {
		$content = stripslashes( $ad ) . $content;
	} else {
		$content;
	}

	return $content;

}
add_filter( 'the_content', 'mystery_single_ad_before', 20 );

/**
 * Single post advertisement.
 * After content.
 *
 * @since  1.0.0
 */
function mystery_single_ad_after( $content ) {
	$ad = of_get_option( 'mystery_ad_single_after' );

	if ( is_single() ) {
		$content = $content . stripslashes( $ad );
	} else {
		$content;
	}

	return $content;

}
add_filter( 'the_content', 'mystery_single_ad_after', 20 );

/**
 * Tracking Code
 *
 * @since  1.0.0
 */
function mystery_tracking_code() {
	$tracking_code = of_get_option( 'mystery_tracking' );

	if ( !empty( $tracking_code ) ) {
		echo stripslashes( $tracking_code ) . "\n";
	}

}
add_action( 'wp_footer', 'mystery_tracking_code', 15 );

/**
 * Header Code
 *
 * @since  1.0.0
 */
function mystery_header_code() {
	$header_code = of_get_option( 'mystery_script_head' );

	if ( !empty( $header_code ) ) {
		echo stripslashes( $header_code ) . "\n";
	}

}
add_action( 'wp_head', 'mystery_header_code', 20 );

/**
 * Footer Code
 *
 * @since  1.0.0
 */
function mystery_footer_code() {
	$footer_code = of_get_option( 'mystery_script_footer' );

	if ( !empty( $footer_code ) ) {
		echo stripslashes( $footer_code ) . "\n";
	}

}
add_action( 'wp_footer', 'mystery_footer_code', 20 );

/**
 * Footer background color.
 *
 * @since  1.0.0
 */
function mystery_footer_bg() {
	$color = of_get_option( 'mystery_footer_color', 'dark' );
	$class = '';

	if ( $color == 'dark' ) {
		$class = 'footer-dark';
	} else {
		$class = 'footer-light';
	}

	return $class;

}