<?php
/**
 * Theme Options.
 *
 * @package    Mystery
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 *
 * @since  1.0.0
 */
function optionsframework_option_name() {
	return 'mystery'; // Theme slug
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * @since  1.0.0
 */
function optionsframework_options() {

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	$options_categories[''] = __( 'All Categories', 'mystery' );
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	$options_tags[''] = __( 'All Tags', 'mystery' );
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}

	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages( 'sort_column=post_parent,menu_order' );
	$options_pages[''] = __( 'Select a page:', 'mystery' );
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// Image path
	$imagepath =  get_template_directory_uri() . '/assets/img/';

	// Set empty $options.
	$options = array();

	/**
	 * Defines array of options.
	 */
	
	// ============================ //
	// ===== General Settings ===== //
	// ============================ //
	$options[] = array(
		'name' => __( 'General', 'mystery' ),
		'type' => 'heading'
	);

		$options['mystery_colors'] = array(
			'name' => __( 'Accent Colors', 'mystery' ),
			'desc' => __( 'Please choose the preset color for your website.', 'mystery' ),
			'id'   => 'mystery_colors',
			'type' => 'radio',
			'std'  => 'blue',
			'options' => array(
				'blue'        => __( 'Blue', 'mystery' ),
				'green'       => __( 'Green', 'mystery' ),
				'deep-green'  => __( 'Deep Green', 'mystery' ),
				'dark-green'  => __( 'Dark Green', 'mystery' ),
				'turqouise'   => __( 'Turqouise', 'mystery' ),
			)
		);

		$options['mystery_color_pallete'] = array(
			'name' => '',
			'desc' => __( 'If you don\' like the preset colors, you can choose the color you like from the pallete.', 'mystery' ),
			'id'   => 'mystery_color_pallete',
			'std'  => '#00aeef',
			'type' => 'color'
		);

		$options['mystery_favicon'] = array(
			'name' => __( 'Favicon', 'mystery' ),
			'desc' => __( 'Your custom favicon. 32x32px recommended.', 'mystery' ),
			'id'   => 'mystery_favicon',
			'type' => 'upload'
		);

		$options['mystery_mobile_icon'] = array(
			'name' => __( 'Mobile Icon', 'mystery' ),
			'desc' => __( '144x144 recommended in PNG format. This icon will be used when users add your website as a shortcut on mobile devices like iPhone, iPad, Android etc.', 'mystery' ),
			'id'   => 'mystery_mobile_icon',
			'type' => 'upload'
		);

		$options[] = array(
			'name'  => __( 'FeedBurner URL', 'mystery' ),
			'desc'  => __( 'Enter your full FeedBurner URL. If you wish to use FeedBurner over the standard WordPress feed.', 'mystery' ),
			'id'    => 'mystery_feedburner_url',
			'placeholder' => 'http://feeds.feedburner.com/ThemeJunkie',
			'type'  => 'text'
		);

		$options['mystery_tracking'] = array(
			'name' => __( 'Tracking Code', 'mystery' ),
			'desc' => __( 'Paste your Google Analytics (or other) tracking code here. It will be inserted before the closing body tag of your theme.', 'mystery' ),
			'id'   => 'mystery_tracking',
			'type' => 'textarea'
		);

	// ============================ //
	// ===== Header Settings ===== //
	// ============================ //
	$options[] = array(
		'name' => __( 'Header', 'mystery' ),
		'type' => 'heading'
	);

		$options['mystery_logo'] = array(
			'name' => __( 'Logo', 'mystery' ),
			'desc' => __( 'Upload your custom logo, it will automatically replace the Site Title', 'mystery' ),
			'id'   => 'mystery_logo',
			'type' => 'upload'
		);

		$options['mystery_logo_retina'] = array(
			'name' => __( 'Retina Logo', 'mystery' ),
			'desc' => __( 'Upload your retina version of your logo. eg: logo@2x.png', 'mystery' ),
			'id'   => 'mystery_logo_retina',
			'type' => 'upload'
		);

		$options[] = array(
			'name' => __( 'Site Description', 'mystery' ),
			'desc' => __( 'Display the site description.', 'mystery' ),
			'id'   => 'mystery_site_desc',
			'std'  => 'on',
			'type' => 'onoff'
		);

		$options[] = array(
			'name' => __( 'Social Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options[] = array(
				'name' => __( 'Enable', 'mystery' ),
				'desc' => __( 'Enable social icons in header.', 'mystery' ),
				'id'   => 'mystery_enable_social_header',
				'std'  => 'on',
				'type' => 'onoff'
			);

			$options[] = array(
				'name'        => __( 'Twitter URL', 'mystery' ),
				'desc'        => __( 'Enter your twitter profile URL.', 'mystery' ),
				'id'          => 'mystery_twitter_url',
				'placeholder' => 'http://twitter.com/',
				'type'        => 'text'
			);

			$options[] = array(
				'name'        => __( 'Facebook URL', 'mystery' ),
				'desc'        => __( 'Enter your facebook profile  URL.', 'mystery' ),
				'id'          => 'mystery_fb_url',
				'placeholder' => 'http://www.facebook.com/',
				'type'        => 'text'
			);

			$options[] = array(
				'name'        => __( 'Google Plus URL', 'mystery' ),
				'desc'        => __( 'Enter your google plus profile  URL.', 'mystery' ),
				'id'          => 'mystery_gplus_url',
				'placeholder' => 'http://plus.google.com/',
				'type'        => 'text'
			);

			$options[] = array(
				'name'  => __( 'Feed URL', 'mystery' ),
				'desc'  => __( 'Enter your website feed URL.', 'mystery' ),
				'id'    => 'mystery_feed_url',
				'std'   => esc_url( get_feed_link() ),
				'type'  => 'text'
			);

		$options[] = array(
			'name' => __( 'Navigation Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options[] = array(
				'name'  => __( 'Sticky navigation', 'mystery' ),
				'desc'  => __( 'Please choose which navigation you want to sticky.', 'mystery' ),
				'id'    => 'mystery_sticky_nav',
				'std'   => 'secondary',
				'type'  => 'radio',
				'options' => array(
					'primary'   => __( 'Primary', 'mystery' ),
					'secondary' => __( 'Secondary', 'mystery' ),
					'disable'   => __( 'Disable', 'mystery' ),
				)
			);

	// ======================================== //
	// ===== Index and Archive Settings ======= //
	// ======================================== //
	$options[] = array(
		'name' => __( 'Index and Archive', 'mystery' ),
		'type' => 'heading'
	);

		$options[] = array(
			'name' => __( 'Sidebar Secondary Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options[] = array(
				'name'  => __( 'Enable Sidebar Secondary', 'mystery' ),
				'desc'  => __( 'enable sidebar secondary on home page.', 'mystery' ),
				'id'    => 'mystery_enable_sidebar_1',
				'std'   => 'on',
				'type'  => 'onoff'
			);

			$options[] = array(
				'name'  => __( 'Sidebar Secondary Position', 'mystery' ),
				'desc'  => __( 'Position of sidebar secondary.', 'mystery' ),
				'id'    => 'mystery_sidebar_1',
				'std'   => 'right',
				'type'  => 'radio',
				'options' => array(
					'right' => __( 'Right', 'mystery' ),
					'left'  => __( 'Left', 'mystery' )
				)
			);

		$options[] = array(
			'name' => __( 'Featured Posts Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options[] = array(
				'name' => __( 'Enable', 'mystery' ),
				'desc' => __( 'Enable featured posts slider.', 'mystery' ),
				'id'   => 'mystery_enable_featured_posts',
				'std'  => 'on',
				'type' => 'onoff'
			);

			$options[] = array(
				'name'    => __( 'Featured Posts Tag', 'mystery' ),
				'desc'    => __( 'Select a tag to be used as Featured Posts.', 'mystery' ),
				'id'      => 'mystery_featured_tag',
				'type'    => 'select',
				'options' => $options_tags
			);

			$options[] = array(
				'name'  => __( 'Limit', 'mystery' ),
				'desc'  => __( 'Number of posts to show.', 'mystery' ),
				'id'    => 'mystery_featured_num',
				'std'   => 3,
				'type'  => 'text'
			);

		$options[] = array(
			'name' => __( 'Posts Listing Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options[] = array(
				'name'  => __( 'What\'s New', 'mystery' ),
				'desc'  => __( 'Customize the What\'s New text.', 'mystery' ),
				'id'    => 'mystery_wn_text',
				'std'   => __( 'What\'s New', 'mystery' ),
				'type'  => 'text'
			);

			$options['mystery_index_layout'] = array(
				'name'   => __( 'Index Posts Layout', 'mystery' ),
				'desc'   => __( 'Choose the index posts layout.', 'mystery' ),
				'id'     => 'mystery_index_layout',
				'std'    => 'grid_1',
				'type'   => 'select',
				'options' => array(
					'grid_1'   => __( 'Grid v1', 'mystery' ),
					'grid_2'   => __( 'Grid v2', 'mystery' ),
					'list_1'   => __( 'List v1', 'mystery' ),
					'list_2'   => __( 'List v2', 'mystery' ),
					'blog_1'   => __( 'Blog v1', 'mystery' ),
					'blog_2'   => __( 'Blog v2', 'mystery' ),
				)
			);

			$options['mystery_category_layout'] = array(
				'name'   => __( 'Category Posts Layout', 'mystery' ),
				'desc'   => __( 'Choose the category archive page posts layout.', 'mystery' ),
				'id'     => 'mystery_category_layout',
				'std'    => 'grid_1',
				'type'   => 'select',
				'options' => array(
					'grid_1'   => __( 'Grid v1', 'mystery' ),
					'grid_2'   => __( 'Grid v2', 'mystery' ),
					'list_1'   => __( 'List v1', 'mystery' ),
					'list_2'   => __( 'List v2', 'mystery' ),
					'blog_1'   => __( 'Blog v1', 'mystery' ),
					'blog_2'   => __( 'Blog v2', 'mystery' ),
				)
			);

			$options['mystery_tag_layout'] = array(
				'name'   => __( 'Tag Posts Layout', 'mystery' ),
				'desc'   => __( 'Choose the tag archive page posts layout.', 'mystery' ),
				'id'     => 'mystery_tag_layout',
				'std'    => 'grid_1',
				'type'   => 'select',
				'options' => array(
					'grid_1'   => __( 'Grid v1', 'mystery' ),
					'grid_2'   => __( 'Grid v2', 'mystery' ),
					'list_1'   => __( 'List v1', 'mystery' ),
					'list_2'   => __( 'List v2', 'mystery' ),
					'blog_1'   => __( 'Blog v1', 'mystery' ),
					'blog_2'   => __( 'Blog v2', 'mystery' ),
				)
			);

			$options['mystery_author_layout'] = array(
				'name'   => __( 'Author Posts Layout', 'mystery' ),
				'desc'   => __( 'Choose the author archive page posts layout.', 'mystery' ),
				'id'     => 'mystery_author_layout',
				'std'    => 'grid_1',
				'type'   => 'select',
				'options' => array(
					'grid_1'   => __( 'Grid v1', 'mystery' ),
					'grid_2'   => __( 'Grid v2', 'mystery' ),
					'list_1'   => __( 'List v1', 'mystery' ),
					'list_2'   => __( 'List v2', 'mystery' ),
					'blog_1'   => __( 'Blog v1', 'mystery' ),
					'blog_2'   => __( 'Blog v2', 'mystery' ),
				)
			);

			$options['mystery_search_layout'] = array(
				'name'   => __( 'Search Posts Layout', 'mystery' ),
				'desc'   => __( 'Choose the search page posts layout.', 'mystery' ),
				'id'     => 'mystery_search_layout',
				'std'    => 'grid_1',
				'type'   => 'select',
				'options' => array(
					'grid_1'   => __( 'Grid v1', 'mystery' ),
					'grid_2'   => __( 'Grid v2', 'mystery' ),
					'list_1'   => __( 'List v1', 'mystery' ),
					'list_2'   => __( 'List v2', 'mystery' ),
					'blog_1'   => __( 'Blog v1', 'mystery' ),
					'blog_2'   => __( 'Blog v2', 'mystery' ),
				)
			);

			$options['mystery_archive_layout'] = array(
				'name'   => __( 'Archive Posts Layout', 'mystery' ),
				'desc'   => __( 'Choose the archive page(date, month, year) posts layout.', 'mystery' ),
				'id'     => 'mystery_archive_layout',
				'std'    => 'grid_1',
				'type'   => 'select',
				'options' => array(
					'grid_1'   => __( 'Grid v1', 'mystery' ),
					'grid_2'   => __( 'Grid v2', 'mystery' ),
					'list_1'   => __( 'List v1', 'mystery' ),
					'list_2'   => __( 'List v2', 'mystery' ),
					'blog_1'   => __( 'Blog v1', 'mystery' ),
					'blog_2'   => __( 'Blog v2', 'mystery' ),
				)
			);

	// ================================ //
	// ===== Single Post Settings ===== //
	// ================================ //
	$options[] = array(
		'name' => __( 'Single Post', 'mystery' ),
		'type' => 'heading'
	);

		$options[] = array(
			'name' => __( 'Facebook Comment Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options[] = array(
				'name' => __( 'Facebook Comment', 'mystery' ),
				'desc' => __( 'Use facebook comment.', 'mystery' ),
				'id'   => 'mystery_fb_comment',
				'std'  => 'off',
				'type' => 'onoff'
			);

			$options[] = array(
				'name'        => __( 'App ID', 'mystery' ),
				'desc'        => __( 'Enter your facebook App ID to enable facebook comment.', 'mystery' ),
				'id'          => 'mystery_fb_appid',
				'type'        => 'text'
			);

		$options[] = array(
			'name' => __( 'Disqus Comment Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options[] = array(
				'name' => __( 'Disqus Comment', 'mystery' ),
				'desc' => __( 'Use disqus comment.', 'mystery' ),
				'id'   => 'mystery_disqus_comment',
				'std'  => 'off',
				'type' => 'onoff'
			);

			$options[] = array(
				'name' => __( 'Disqus Shortname', 'mystery' ),
				'desc' => __( 'Enter your disqus shortname.', 'mystery' ),
				'id'   => 'mystery_disqus_shortname',
				'type' => 'text'
			);

		$options[] = array(
			'name' => __( 'Post Misc Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options['mystery_post_navigation'] = array(
				'name' => __( 'Post Navigation', 'mystery' ),
				'desc' => __( 'Display the post navigation.', 'mystery' ),
				'id'   => 'mystery_post_navigation',
				'std'  => 'on',
				'type' => 'onoff'
			);

			$options['mystery_share_buttons'] = array(
				'name' => __( 'Share Buttons', 'mystery' ),
				'desc' => __( 'Display the social share buttons info.', 'mystery' ),
				'id'   => 'mystery_share_buttons',
				'std'  => 'on',
				'type' => 'onoff'
			);

		$options[] = array(
			'name' => __( 'Related Posts Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options['mystery_related_posts'] = array(
				'name' => __( 'Related Posts', 'mystery' ),
				'desc' => __( 'Display the related posts.', 'mystery' ),
				'id'   => 'mystery_related_posts',
				'std'  => 'on',
				'type' => 'onoff'
			);

			$options[] = array(
				'name' => __( 'Related Posts Thumbnail', 'mystery' ),
				'desc' => __( 'Display the related posts with thumbnail.', 'mystery' ),
				'id'   => 'mystery_related_posts_thumbnail',
				'std'  => 'on',
				'type' => 'onoff'
			);

			$options[] = array(
				'name' => __( 'Related Posts Date', 'mystery' ),
				'desc' => __( 'Display the related posts with date.', 'mystery' ),
				'id'   => 'mystery_related_posts_date',
				'std'  => 'off',
				'type' => 'onoff'
			);

		$options[] = array(
			'name' => __( 'Advertisement Settings', 'mystery' ),
			'id'   => '',
			'type' => 'seperator'
		);

			$options['mystery_ad_single_before'] = array(
				'name' => __( 'Before Content Advertisement', 'mystery' ),
				'desc' => __( 'Your ad will appear on single post before content.', 'mystery' ),
				'id'   => 'mystery_ad_single_before',
				'type' => 'textarea'
			);

			$options['mystery_ad_single_after'] = array(
				'name' => __( 'After Content Advertisement', 'mystery' ),
				'desc' => __( 'Your ad will appear on single post after content.', 'mystery' ),
				'id'   => 'mystery_ad_single_after',
				'type' => 'textarea'
			);

	// =========================== //
	// ===== Footer Settings ===== //
	// =========================== //
	$options[] = array(
		'name' => __( 'Footer', 'mystery' ),
		'type' => 'heading'
	);

		$options['mystery_footer_text'] = array(
			'name' => __( 'Footer Text', 'mystery' ),
			'desc' => __( 'You can customize the footer text here.', 'mystery' ),
			'id'   => 'mystery_footer_text',
			'std'  => '&copy; Copyright ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; Designed by <a href="http://www.theme-junkie.com/">Theme Junkie</a>',
			'type' => 'editor'
		);

		$options['mystery_footer_color'] = array(
			'name'  => __( 'Footer Color', 'mystery' ),
			'desc'  => __( 'Pick the background color of the footer.', 'mystery' ),
			'id'    => 'mystery_footer_color',
			'std'   => 'dark',
			'type'  => 'radio',
			'options' => array(
				'dark'  => __( 'Dark', 'mystery' ),
				'light' => __( 'Light', 'mystery' )
			)
		);

	// ================================== //
	// ===== Advertisement Settings ===== //
	// ================================== //
	$options[] = array(
		'name' => __( 'Advertisement', 'mystery' ),
		'type' => 'heading'
	);

		$options['mystery_header_ad'] = array(
			'name' => __( 'Header Advertisement', 'mystery' ),
			'desc' => __( 'The ad will appear at the top of your site. Recommended size 728x90', 'mystery' ),
			'id'   => 'mystery_header_ad',
			'type' => 'textarea'
		);

	// ================================== //
	// ===== Custom Code Settings ======= //
	// ================================== //
	$options[] = array(
		'name' => __( 'Custom Code', 'mystery' ),
		'type' => 'heading'
	);

		$options['mystery_script_head'] = array(
			'name' => __( 'Header code', 'mystery' ),
			'desc' => __( 'If you need to add custom scripts to your header (meta tag verification, google fonts url), you should enter them in the box. They will be added before &lt;/head&gt; tag', 'mystery' ),
			'id'   => 'mystery_script_head',
			'type' => 'textarea'
		);

		$options['mystery_script_footer'] = array(
			'name' => __( 'Footer code', 'mystery' ),
			'desc' => __( 'If you need to add custom scripts to your footer, you should enter them in the box. They will be added before &lt;/body&gt; tag', 'mystery' ),
			'id'   => 'mystery_script_footer',
			'type' => 'textarea'
		);
	
	// Allow dev to filter the theme options.
	return apply_filters( 'mystery_theme_options', $options );
}