<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 * 
 * @package    Mystery
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'mystery_site_branding' ) ) {
	/**
	 * Site branding for the site.
	 * 
	 * Display site title by default, but user can change it with their custom logo.
	 * They can upload it on Customizer page.
	 * 
	 * @since  1.0.0
	 */
	function mystery_site_branding() {

		// Check if logo available, then display it.
		if ( of_get_option( 'mystery_logo' ) ) :
			echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
				echo '<a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
					echo '<img itemprop="logo" src="' . esc_url( of_get_option( 'mystery_logo' ) ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
				echo '</a>' . "\n";
			echo '</div>' . "\n";

		// If not, then display the Site Title and Site Description.
		else :
			echo '<div id="logo">'. "\n";
				echo '<h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr( get_bloginfo( 'name' ) ) . '</span></a></h1>'. "\n";
				if ( of_get_option( 'mystery_description', 'on' ) == 'on' ) :
					echo '<h2 class="site-description" ' . hybrid_get_attr( 'site-description' ) . '>' . esc_attr( get_bloginfo( 'description' ) ) . '</h2>';
				endif;
			echo '</div>'. "\n";
		endif;

	}
}

if ( ! function_exists( 'mystery_header_ad' ) ) {
	/**
	 * Header ad.
	 *
	 * @since  1.0.0
	 */
	function mystery_header_ad() {

		// Get the ad code.
		$ad = of_get_option( 'mystery_header_ad' );

		// Display the ad.
		if ( ! empty( $ad ) ) {
			echo '<div class="header-ad">' . stripslashes( $ad ) . '</div>';
		}

	}
}

if ( ! function_exists( 'mystery_header_social' ) ) {
	/**
	 * Social icons in header.
	 *
	 * @since  1.0.0
	 */
	function mystery_header_social() {

		// Get the social url.
		$enable     = of_get_option( 'mystery_enable_social_header', 'on' );
		$twitter    = of_get_option( 'mystery_twitter_url' );
		$facebook   = of_get_option( 'mystery_fb_url' );
		$gplus      = of_get_option( 'mystery_gplus_url' );
		$feed       = of_get_option( 'mystery_feed_url', of_get_default( 'mystery_feed_url' ) );

		// Check if social links option enabled.
		if ( $enable == 'on' ) {

			echo '<div class="header-social">';

				if ( ! empty( $facebook ) ) {
					echo '<a href="' . esc_url( $facebook ) . '" rel="tipsy" title="Facebook"><i class="fa fa-facebook"></i></a>';
				}
				if ( ! empty( $twitter ) ) {
					echo '<a href="' . esc_url( $twitter ) . '" rel="tipsy" title="Twitter"><i class="fa fa-twitter"></i></a>';
				}
				if ( ! empty( $gplus ) ) {
					echo '<a href="' . esc_url( $gplus ) . '" rel="tipsy" title="GooglePlus"><i class="fa fa-google-plus"></i></a>';
				}
				if ( ! empty( $feed ) ) {
					echo '<a href="' . esc_url( $feed ) . '" rel="tipsy" title="RSS"><i class="fa fa-rss"></i></a>';
				}

			echo  '</div>';

		}

	}
}

if ( ! function_exists( 'mystery_featured_content' ) ) {
	/**
	 * Featured content.
	 *
	 * @since  1.0.0
	 */
	function mystery_featured_content() {
		global $cat;

		// Data from theme options.
		$enable = of_get_option( 'mystery_enable_featured_posts', 'on' );
		$tag    = of_get_option( 'mystery_featured_tag' );
		$num    = of_get_option( 'mystery_featured_num', 3 );

		// Don't show featured content on single or paged page.
		if ( is_single() || is_paged() ) {
			return;
		}

		// Check if it enabled.
		if ( $enable == 'off' ) {
			return;
		}

		// Posts query arguments.
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => absint( $num )
		);

		// Limit to tag based on user selected tag.
		if ( ! empty( $tag ) ) {
			$args['tag_id'] = $tag;
		}

		// If on category archive page.
		if ( is_category() ) {
			$args['cat'] = $cat;
		}

		// Allow dev to filter the post arguments.
		$query = apply_filters( 'mystery_featured_args', $args );

		// The post query.
		$featured = new WP_Query( $query );

		// Check if the post(s) exist.
		if ( $featured->have_posts() ) : ?>

			<?php if ( is_category() ) : ?>
				<h1 class="section-title"><strong><?php printf( __( 'Featured on %s', 'mystery' ), single_cat_title( '', false ) ); ?></strong></h1>
			<?php endif; ?>

			<div id="featured-content" class="slider clearfix">
				<div class="flexslider">
					<ul class="slides">
						
						<?php while ( $featured->have_posts() ) : $featured->the_post(); ?>
							
							<li class="hentry post">
								<?php get_template_part( 'content', 'featured' ); // Featured content template. ?>
							</li>

						<?php endwhile; ?>

					</ul>
				</div>
			</div>

		<?php endif; // End check.

		// Restore original Post Data.
		wp_reset_postdata();

	}
}

if ( ! function_exists( 'mystery_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 *
	 * @since 1.0.0
	 */
	function mystery_posted_on() {
		?>
		<div class="entry-meta">
		
			<?php if ( 'post' == get_post_type() && ! is_single() ) : ?>
				<?php
					$category = get_the_category( get_the_ID() );
					if ( $category && mystery_categorized_blog() ) :
				?>
				<span class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
					<a href="<?php echo esc_url( get_category_link( $category[0]->term_id ) ); ?>"><?php echo esc_attr( $category[0]->name ); ?></a>
				</span>
				<?php endif; // End if categories ?>

				<span class="sep">|</span>

			<?php endif; // End if 'post' == get_post_type() ?>
			
			<?php if ( is_single() ) : ?>
				<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'flatline_author_bio_avatar_size', 48 ), '', strip_tags( get_the_author() ) ); ?>

				<span class="entry-author author vcard" <?php hybrid_attr( 'entry-author' ) ?>><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" itemprop="url"><span itemprop="name"><?php echo esc_html( get_the_author() ); ?></span></a></span>
			<?php endif; ?>

			<span class="entry-date">
				<time class="published" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ) ?>><?php echo esc_html( get_the_date() ); ?></time>
			</span>

			<span class="sep">|</span>

			<span class="entry-views">
				<?php $views = intval( get_post_meta( get_the_ID(), 'Views', true ) ); echo number_format_i18n( $views ); ?>
			</span>

			<span class="sep">|</span>

			<?php mystery_comment_count(); ?>
			
			<?php if ( is_single() && of_get_option( 'mystery_tags', 'on' ) == 'on' ) : ?>
				<span class="sep">|</span>

				<?php
					$tag_list = get_the_tag_list( '', ', ' );
					if ( $tag_list ) : 
				?>
					<span class="entry-tags" <?php hybrid_attr( 'entry-terms', 'post_tag' ); ?>><i class="fa fa-tags"></i> <?php echo $tag_list; ?></span>
				<?php endif; ?>
			<?php endif; ?>

		</div>

		<?php
	}
}

if ( ! function_exists( 'mystery_social_share' ) ) {
	/**
	 * Header ad.
	 *
	 * @since  1.0.0
	 */
	function mystery_social_share() {
		global $post;

		// Disable social share.
		if ( of_get_option( 'mystery_share_buttons', 'on' ) != 'on' ) {
			return;
		}

		?>
		<div class="entry-share clearfix">
			<ul>
				<li class="twitter"><a href="https://twitter.com/intent/tweet?text=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>&url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" target="_blank"><i class="fa fa-twitter"></i>Twitter</a></li>
				<li class="facebook"><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" target="_blank"><i class="fa fa-facebook"></i>Facebook</a></li>
				<li class="google-plus"><a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" target="_blank"><i class="fa fa-google-plus"></i>Google+</a></li>
				<li class="linkedin"><a href="https://www.linkedin.com/shareArticle?mini=true&url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&title=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>" target="_blank"><i class="fa fa-linkedin"></i>LinkedIn</a></li>
				<li class="pinterest"><a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&media=<?php echo urlencode( wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) ) ); ?>" target="_blank"><i class="fa fa-pinterest"></i>Pinterest</a></li>				
				<li class="email"><a href="mailto:"><i class="fa fa-envelope-o"></i>Email</a></li>
			</ul>
		</div><!-- .entry-share -->
		<?php
	}
}

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function mystery_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'mystery_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'mystery_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so mystery_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so mystery_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in mystery_categorized_blog.
 *
 * @since 1.0.0
 */
function mystery_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'mystery_categories' );
}
add_action( 'edit_category', 'mystery_category_transient_flusher' );
add_action( 'save_post',     'mystery_category_transient_flusher' );

if ( ! function_exists( 'mystery_post_author' ) ) {
	/**
	 * Author post informations.
	 *
	 * @since  1.0.0
	 */
	function mystery_post_author() {

		// Bail if user don't want to display the author info via theme settings.
		if ( of_get_option( 'mystery_post_author', 'on' ) != 'on' ) {
			return;
		}

		// Bail if not on the single post.
		if ( ! is_single() ) {
			return;
		}

		// Bail if user hasn't fill the Biographical Info field.
		if ( ! get_the_author_meta( 'description' ) ) {
			return;
		}
	?>

		<div class="author-bio clearfix" <?php hybrid_attr( 'entry-author' ) ?>>
			<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'mystery_author_bio_avatar_size', 64 ), '', strip_tags( get_the_author() ) ); ?>
			<div class="description">
				<h3 class="author-title name">
					<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author" itemprop="url"><span itemprop="name"><?php echo strip_tags( get_the_author() ); ?></span></a>
				</h3>
				<p class="bio" itemprop="description"><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>
			</div>
		</div><!-- .author-bio -->

	<?php
	}
}

if ( ! function_exists( 'mystery_related_posts' ) ) {
	/**
	 * Related posts.
	 *
	 * @since  1.0.0
	 */
	function mystery_related_posts() {
		global $post;

		// Bail if user don't want to display the related posts via theme settings.
		if ( of_get_option( 'mystery_related_posts', 'on' ) != 'on' ) {
			return;
		}

		// Get the taxonomy terms of the current page for the specified taxonomy.
		$terms = wp_get_post_terms( $post->ID, 'category', array( 'fields' => 'ids' ) );

		// Bail if the term empty.
		if ( empty( $terms ) ) {
			return;
		}
		
		// Posts query arguments.
		$query = array(
			'post__not_in' => array( $post->ID ),
			'tax_query'    => array(
				array(
					'taxonomy' => 'category',
					'field'    => 'id',
					'terms'    => $terms,
					'operator' => 'IN'
				)
			),
			'posts_per_page' => 4,
			'post_type'      => 'post',
		);

		// Allow dev to filter the query.
		$args = apply_filters( 'mystery_related_posts_args', $query );

		// The post query
		$related = new WP_Query( $args );

		if ( $related->have_posts() ) : ?>

			<div class="related-posts">
				<h3><?php _e( 'Recommended for You', 'mystery' ); ?></h3>
				<ul class="clearfix">
					<?php while ( $related->have_posts() ) : $related->the_post(); ?>
						<li>
							<a href="<?php the_permalink(); ?>">
								<?php if ( of_get_option( 'mystery_related_posts_thumbnail', 'on' ) == 'on' && has_post_thumbnail() ) : ?>
									<?php the_post_thumbnail( 'mystery-related', array( 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php endif; ?>
								<?php the_title( '<h2 class="entry-title">', '</h2>' ); ?>
								<?php if ( of_get_option( 'mystery_related_posts_date', 'on' ) == 'on' ) : ?>
									<time class="entry-date published" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>"><?php echo esc_html( get_the_date() )?></time>
								<?php endif; ?>
							</a>
						</li>
					<?php endwhile; ?>
				</ul>
			</div>
		
		<?php endif;

		// Restore original Post Data.
		wp_reset_postdata();

	}
}

if ( ! function_exists( 'mystery_comment' ) ) {
	/**
	 * Template for comments and pingbacks.
	 *
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 *
	 * @since  1.0.0
	 */
	function mystery_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
			// Display trackbacks differently than normal comments.
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
			<article id="comment-<?php comment_ID(); ?>" class="comment-container">
				<p <?php hybrid_attr( 'comment-content' ); ?>><?php _e( 'Pingback:', 'mystery' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( __( '(Edit)', 'mystery' ), '<span class="edit-link">', '</span>' ); ?></p>
			</article>
		<?php
				break;
			default :
			// Proceed with normal comments.
			global $post;
		?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
			<article id="comment-<?php comment_ID(); ?>" class="comment-container">

				<?php echo get_avatar( $comment, apply_filters( 'mystery_comment_avatar_size', 52 ) ); ?>

				<div class="comment-head">
					<span class="name" <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
					<?php
						printf( '<span class="date"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> %4$s</span>',
							esc_url( get_comment_link( $comment->comment_ID ) ),
							get_comment_time( 'c' ),
							/* translators: 1: date, 2: time */
							sprintf( __( '%1$s at %2$s', 'mystery' ), get_comment_date(), get_comment_time() ),
							sprintf( __( '%1$s&middot; Edit%2$s', 'mystery' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'mystery' ) . '">', '</a>' )
						);
					?>
				</div><!-- comment-head -->
				
				<div class="comment-content comment-entry comment" <?php hybrid_attr( 'comment-content' ); ?>>
					<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'mystery' ); ?></p>
					<?php endif; ?>
					<?php comment_text(); ?>
					<span class="reply">
						<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'mystery' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
					</span><!-- .reply -->
				</div><!-- .comment-content -->

			</article><!-- #comment-## -->
		<?php
			break;
		endswitch; // end comment_type check
	}
}

if ( ! function_exists( 'mystery_comment_count' ) ) {
	/**
	 * Comment count
	 *
	 * @since  1.0.0
	 */
	function mystery_comment_count() {
		?>
		<?php if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>

			<?php if ( of_get_option( 'mystery_fb_comment' ) == 'on' ) : ?>
				<span class="entry-comments"><i class="fa fa-comment-o"></i> <span class="fb-comments-count" data-href="<?php the_permalink(); ?>"></span></span>
			<?php elseif ( of_get_option( 'mystery_disqus_comment' ) == 'on' ) : ?>
				<span class="entry-comments"><a href="<?php the_permalink(); ?>#disqus_thread"><i class="fa fa-comment-o"></i></a></span>
			<?php else : ?>
				<span class="entry-comments"><i class="fa fa-comment-o"></i> <?php comments_popup_link( __( '0', 'mystery' ), __( '1', 'mystery' ), __( '%', 'mystery' ) ); ?></span>
			<?php endif; ?>

		<?php endif; ?>
		<?php
	}
}